@@ -9,11 +9,6 @@
 #include <new>
 
 extern "C" {
-#define delete		delete_
-#define namespace	namespace_
-#define	typeid		typeid_
-#define	typename	typename_
-#define	using		using_
 
 #if PG_VERSION_NUM >= 90300
 #include "access/htup_details.h"
@@ -191,7 +186,7 @@ void
 _PG_init(void)
 {
 	HASHCTL    hash_ctl = { 0 };
-	
+
 	hash_ctl.keysize = sizeof(Oid);
 	hash_ctl.entrysize = sizeof(plv8_proc_cache);
 	hash_ctl.hash = oid_hash;
@@ -1263,6 +1258,18 @@ ThrowError(const char *message) throw()
 	return ThrowException(Exception::Error(String::New(message)));
 }
 
+static text *
+charToText(char *string)
+{
+	int len = strlen(string);
+	text *result = (text *) palloc(len + 1 + VARHDRSZ);
+
+	SET_VARSIZE(result, len + VARHDRSZ);
+	memcpy(VARDATA(result), string, len + 1);
+
+	return result;
+}
+
 static Persistent<Context>
 GetGlobalContext()
 {
@@ -1307,10 +1314,37 @@ GetGlobalContext()
 			Context::Scope		context_scope(global_context);
 			TryCatch			try_catch;
 			MemoryContext		ctx = CurrentMemoryContext;
+			text *arg;
+			FunctionCallInfoData fake_fcinfo;
+			FmgrInfo	flinfo;
+
+			char perm[16];
+			strcpy(perm, "EXECUTE");
+			arg = charToText(perm);
+			Oid funcoid = DatumGetObjectId(DirectFunctionCall1(regprocin, CStringGetDatum(plv8_start_proc)));
+
+			MemSet(&fake_fcinfo, 0, sizeof(fake_fcinfo));
+			MemSet(&flinfo, 0, sizeof(flinfo));
+			fake_fcinfo.flinfo = &flinfo;
+			flinfo.fn_oid = InvalidOid;
+			flinfo.fn_mcxt = CurrentMemoryContext;
+			fake_fcinfo.nargs = 2;
+			fake_fcinfo.arg[0] = ObjectIdGetDatum(funcoid);
+			fake_fcinfo.arg[1] = CStringGetDatum(arg);
 
 			PG_TRY();
 			{
-				func = find_js_function_by_name(plv8_start_proc);
+				Datum ret = has_function_privilege_id(&fake_fcinfo);
+
+				if (ret == 0) {
+					elog(WARNING, "failed to find js function %s", plv8_start_proc);
+				} else {
+					if (DatumGetBool(ret)) {
+						func = find_js_function_by_name(plv8_start_proc);
+					} else {
+						elog(WARNING, "no permission to execute js function %s", plv8_start_proc);
+					}
+				}
 			}
 			PG_CATCH();
 			{
